@@ -1,4 +1,4 @@
-/* $Id: common.c,v 1.1.1.1 1998/12/02 16:51:38 roca Exp $ */
+/* $Id: common.c,v 1.7 1999/03/02 16:38:10 roca Exp $ */
 /*
  * common.c
  *
@@ -8,8 +8,8 @@
  *	bench/benchd common routines.
  */
 /*
- * (c) Copyright 1998 - V. Roca: this tool is provided as is, without
- * any warranty.
+ * (c) Copyright 1998/1999 - V. Roca (vincent.roca@lip6.fr)
+ * This tool is provided as is, without any warranty.
  * Permission to use, copy and modify is provided for non commercial
  * purposes as long as this notice appears on all copies.
  */
@@ -17,8 +17,10 @@
 #include "bench.h"
 #include "bench_proto.h"
 
+#ifdef SOLARIS
 extern char *optarg;
 extern int getopt();
+#endif
 
 
 /****** parameter parsing ******/
@@ -89,7 +91,7 @@ ParseCommandLine (int	argc,
 			if (!strcmp(optarg,"tt")) {
 				mode = RTT_MODE;
 			}
-#if defined(LINUX) || defined(BOSX32) || defined(BOSX41)
+#if defined(LINUX) || defined(SOLARIS) || defined(BOSX41)
 			else if (*optarg == 't') {
 				if (isdigit(*(++optarg)))
 					rt_pri = atoi(optarg);
@@ -112,23 +114,16 @@ ParseCommandLine (int	argc,
 					/* Number of us between two sends */
 					rate_interval = (int)(1000000.0 /
 							      (float)rate);
-#ifdef NEVERDEF
-					if (rate_interval < 100) {
-						rate_interval = 1;
-						PRINT_OUT((stdout, "bench: rate parameter not realistic, time interval set to %d us\n", rate_interval))
-					}
-#else  /* NEVERDEF */
 					/*
 					 * if we'd wait less than 20 ms, then
 					 * use bursts instead
 					 */
 					if (rate_interval < 20000) {
 						rate_interval = 20000;
-						pkts_in_burst = ceil((float)rate * (float)rate_interval * 1e-6);
-						PRINT_OUT((stdout, "bench: high rate: bursts of %d packets every %d us\n", pkts_in_burst, rate_interval))
+						pkts_in_burst = (int) ceil((double)rate * (double)rate_interval * 1e-6);
+						/* PRINT_OUT((stdout, "bench: high rate: bursts of %d packets every %d us\n", pkts_in_burst, rate_interval)) */
 					} else
 						pkts_in_burst = 1;
-#endif /* NEVERDEF */
 				} else {
 					PRINT_ERR((stderr,
 						"bad argument -r%s\n", optarg))
@@ -136,10 +131,11 @@ ParseCommandLine (int	argc,
 				}
 			}
 #endif /* CLIENT */
-#ifdef SERVER
 			else if (!strcmp(optarg,"aw")) {
 				raw = 1;
-			} else if (*optarg == 'b' && *(optarg+1) == 'u' &&
+			}
+#ifdef SERVER
+			else if (*optarg == 'b' && *(optarg+1) == 'u' &&
 				 *(optarg+2) == 'f') {
 				if (isdigit(*(optarg+3)))
 					recbuf_size = atoi(optarg+3);
@@ -175,14 +171,12 @@ ParseCommandLine (int	argc,
 					"invalid IP address %s\n", optarg+3))
 					UsageHelp(argv[0]);
 				}
-printf("adr=%d\n",raddr.s_addr);
 			} else if (isdigit(*optarg)) {
 				if(( raddr.s_addr = inet_addr((char *)optarg)) == -1) {
         				PRINT_ERR((stderr,
 					"invalid IP address %s\n", optarg))
 					UsageHelp(argv[0]);
 				}
-printf("adr=%d\n",raddr.s_addr);
 			} else {
 				PRINT_ERR((stderr,"bad argument -a%s\n",optarg))
 				UsageHelp(argv[0]);
@@ -193,7 +187,7 @@ printf("adr=%d\n",raddr.s_addr);
 				strcpy(myport, optarg);
 				eport++;
 			}
-#if defined(LINUX) || defined(BOSX32) || defined(BOSX41)
+#if defined(LINUX) || defined(SOLARIS) || defined(BOSX41)
 			else if (!strcmp(optarg,"in"))
 				pin = 1;
 #endif /* BOSX */
@@ -249,7 +243,11 @@ printf("adr=%d\n",raddr.s_addr);
 				silent = 1;
 			else if (!strcmp(optarg,"ync"))
 				syncf = 1;
-			else {
+			else if (*optarg == 's' && *(optarg+1) == 'i' &&
+				 *(optarg+2) == 'z' && *(optarg+3) == 'e' &&
+				isdigit(*(optarg+4))) {
+				sock_size = atoi(optarg+4);
+			} else {
 				PRINT_ERR((stderr, "bad argument -s%s\n", optarg))
 				Usage(-1, argv[0], 0);
 			}
@@ -257,10 +255,8 @@ printf("adr=%d\n",raddr.s_addr);
 		case 'k':
 			if (*optarg == 'B')
 				units = KILOBYTES_PER_SEC;
-#ifdef NOT_YET
 			else if (*optarg == 'b')
 				units = KILOBITS_PER_SEC;
-#endif /* NOT_YET */
 			else {
 				PRINT_ERR((stderr, "bad argument -k%s\n", optarg))
 				Usage(-1, argv[0], 0);
@@ -323,11 +319,11 @@ printf("adr=%d\n",raddr.s_addr);
 				mcast = 1;
 				udp = 1;
 			} else
-#ifdef MTRACE
+#if defined(MTRACE) && defined(BOSX41)
 			if (!strcmp(optarg,"trace")) {
 				mtrace = 1;
 			} else
-#endif /* MTRACE */
+#endif /* MTRACE && BOSX41 */
 			if (isdigit(*optarg)) {
 				tmsg = atoi(optarg);
 				if (tmsg <= 0)
@@ -507,7 +503,7 @@ PrintParams (void)
 	for (i = 0 ; i < lgthmsg ; i++)
 		sndbuf[i] = (char)i;
 
-#ifdef LINUX
+#if defined(LINUX) || defined(SOLARIS)
 	/*
 	 * NB: we can set real-time properties here since it is
 	 * inherited across a fork.
@@ -520,10 +516,11 @@ PrintParams (void)
 		sp.sched_priority = rt_pri;
 		if (sched_setscheduler(0, SCHED_FIFO, &sp) < 0) {
 			perror("bench: sched_setscheduler");
+			printf("bench: errno=%d\n", errno);
 			exit(-1);
 		}
 	}
-#elif defined(BOSX32) || defined(BOSX41)
+#elif defined(BOSX41)
 	if (rt_pri > 0) {
 		/* Change to a fixed real-time priority */
 		if (setpri(getpid(), rt_pri) < 0) {
@@ -578,7 +575,7 @@ PrintParams (void)
 #endif /* XTI */
 #ifdef CLIENT
 	if (rate)
-		PRINT_OUT((stdout, "%s send rate :\t%d Msg/s, %d pkts in burst, %d us interval\n",
+		PRINT_OUT((stdout, "%s send rate :\t%d Msg/s (theory), %d pkts in burst, %d us interval\n",
 			   SIDE, rate, pkts_in_burst, rate_interval))
 #endif /* CLIENT */
 	if (rt_pri > 0)
@@ -588,7 +585,7 @@ PrintParams (void)
 		PRINT_OUT((stdout, "%s address :\t%ld\n", SIDE, (long)(raddr.s_addr)))
 #ifdef CLIENT	/* because a server won't use any hostname */
 	else
-		PRINT_OUT((stdout, "%s remote hostname:\t%s\n", SIDE, rname))
+		PRINT_OUT((stdout, "%s remote host :\t%s\n", SIDE, rname))
 #endif /* CLIENT */
 	if (eport)
 		PRINT_OUT((stdout, "%s port number :\t%s\n", SIDE, myport))
@@ -606,18 +603,52 @@ PrintParams (void)
 	PRINT_OUT((stdout, "%s length of msg :\t%d\n", SIDE, lgthmsg))
 	if (!udp && !bcast && !mcast)
 		PRINT_OUT((stdout, "%s nb of connect :\t%d\n", SIDE, nbconn))
-	if (nbconn > 1)
-		PRINT_OUT((stdout, "%s connect delay :\t%d ms\n", SIDE, delay))
+	/*
+	 * if (nbconn > 1)
+	 * 	PRINT_OUT((stdout, "%s connect delay :\t%d ms\n", SIDE, delay))
+	 */
 #endif /* CLIENT */
+
 #ifdef SERVER
 	PRINT_OUT((stdout, "%s recv buffer :\t%d bytes\n", SIDE, recbuf_size))
 #else  /* SERVER */
 	if (mode == RTT_MODE)
-		PRINT_OUT((stdout, "%s recv buffer :\t%d bytes\n", SIDE, recbuf_size))
+		PRINT_OUT((stdout, "%s recv buffer :\t%d bytes\n", SIDE,
+			   recbuf_size))
 #endif /* SERVER */
-	PRINT_OUT((stdout, "%s units :\t\t%s\n", SIDE, 
-		(units == MEGABITS_PER_SEC) ? "Mbps" : "kBps"))
-	PRINT_OUT((stdout, "%s trace period :\t%d seconds\n", SIDE, tmsg))
+	if (!raw) {
+		switch (units) {
+		case MEGABITS_PER_SEC:
+			PRINT_OUT((stdout,
+			"%s units :\t\tMbps (10^6 bits per second)\n", SIDE))
+			break;
+		case KILOBITS_PER_SEC:
+			PRINT_OUT((stdout,
+			"%s units :\t\tkbps (10^3 bits per second)\n", SIDE))
+			break;
+		default:
+			PRINT_OUT((stdout,
+			"%s units :\t\tkBps (1024 bytes per second)\n", SIDE))
+			break;
+		}
+	}
+	if (raw) {
+		PRINT_OUT((stdout, "\n--------------------------------------------------------------------------------\n"))
+#ifdef SERVER
+		if (udp) {
+			PRINT_OUT((stdout, "timestamp(s)\t\tSize(bytes) Message_sequence_nb Transit_Time(ms) Lost_messages/s\n"))
+		} else {
+			PRINT_OUT((stdout, "timestamp(s)\t\tSize(bytes)\n"))
+		}
+#else  /* CLIENT case */
+		if (udp) {
+			PRINT_OUT((stdout, "timestamp(s)\t\tSize(bytes) Message_sequence_nb Transit_Time(ms)\n"))
+		} else {
+			PRINT_OUT((stdout, "timestamp(s)\t\tSize(bytes) Transit_Time(ms)\n"))
+		}
+#endif /* SERVER/CLIENT */
+	} else
+		PRINT_OUT((stdout, "%s trace period :\t%d seconds\n", SIDE, tmsg))
 }
 
 
@@ -658,7 +689,7 @@ UsageHelp  (char	*proc)
 	PRINT_OUT((stdout, "\nNetwork performance evaluation environment\n"))
 
 	/* Edit version number as appropriate... */
-	PRINT_OUT((stdout, "Version 0.92.0 - vincent.roca@lip6.fr\n\n"))
+	PRINT_OUT((stdout, "Version 0.92.2 - vincent.roca@lip6.fr\n\n"))
 
 	PRINT_OUT((stdout, "%s usage:\n", proc))
 	PRINT_OUT((stdout, "	-help	print this page\n"))
@@ -717,20 +748,18 @@ UsageHelp  (char	*proc)
 	PRINT_OUT((stdout, "  Units:\n"))
 	PRINT_OUT((stdout, "	-kB	results in kilobytes/s (1024) (default)\n"))
 	PRINT_OUT((stdout, "	-Mb	results in megabits/s (10^6)\n"))
+	PRINT_OUT((stdout, "	-kb	results in kilobits/s (10^3)\n"))
 #ifdef NOT_YET
 	PRINT_OUT((stdout, "	-MB	results in megabytes/s (10^6)\n"))
-	PRINT_OUT((stdout, "	-kb	results in kilobits/s (1024)\n"))
 #endif /* NOT_YET */
 
 	/******/
 	PRINT_OUT((stdout, "  Various options:\n"))
-#ifdef SERVER
 	PRINT_OUT((stdout, "	-raw	raw mode: no stats, print each pkt\n"))
-#endif /* SERVER */
 	PRINT_OUT((stdout, "	-V	verbose mode for more stats\n"))
 	PRINT_OUT((stdout, "	-sync	synchronize benchd with bench\n"))
 	PRINT_OUT((stdout, "	-nodelay set nodelay option of tcp on (default is off)\n"))
-#if defined(BOSX32) || defined(BOSX41)
+#if defined(LINUX)
 	PRINT_OUT((stdout, "	-rtR	use real-time process of priority R (must be root)\n"))
 #ifdef SERVER
 	PRINT_OUT((stdout, "		(default %d)\n", BENCHD_PRI))
@@ -738,7 +767,7 @@ UsageHelp  (char	*proc)
 	PRINT_OUT((stdout, "		(default %d)\n", BENCH_PRI))
 #endif
 	PRINT_OUT((stdout, "	-pin	pin code and data in memory\n"))
-#elif defined(BOSX32) || defined(BOSX41)
+#elif defined(BOSX41)
 	PRINT_OUT((stdout, "	-rtR	use real-time process of priority R (must be root)\n"))
 	PRINT_OUT((stdout, "		(default %d)\n", BENCH_PRI))
 	PRINT_OUT((stdout, "	-pin	pin code and data in memory\n"))
@@ -752,13 +781,16 @@ UsageHelp  (char	*proc)
 	PRINT_OUT((stdout, "	-mM	print trace reports every M seconds (default is %d)\n", DEF_TIME_TRACE))
 	PRINT_OUT((stdout, "	-dtonly	print trace reports during data transfer only\n"))
 	PRINT_OUT((stdout, "		(i.e. w/o conn setup and release)\n"))
+#ifdef XTI
 	PRINT_OUT((stdout, "	-vern	use send version n:\n"))
 	PRINT_OUT((stdout, "			0: use send (Socket) or t_snd (XTI)(default)\n"))
 	PRINT_OUT((stdout, "			1: use write directly\n"))
 	PRINT_OUT((stdout, "		use receive version n (rtt mode):\n"))
 	PRINT_OUT((stdout, "			3: use recv (Socket) or t_rcv (XTI) (default)\n"))
 	PRINT_OUT((stdout, "			4: use read directly\n"))
+#endif /* XTI */
 	PRINT_OUT((stdout, "	-rbufR	set receive buffer to R bytes (default is %d)\n", DEF_RCVBUF_SIZE))
+	PRINT_OUT((stdout, "	-ssizeR set receive/send socket sizes to R bytes\n"))
 #if defined(MTRACE) && defined(BOSX41)
 	PRINT_OUT((stdout, "	-mtrace	start the instruction count tool\n"))
 #endif /* MTRACE && BOSX41 */
